@@ -15,13 +15,12 @@
 import ast
 import copy
 import json
-import netaddr
 import re
 
 from django.core.urlresolvers import reverse
 from django.core import validators as django_validator
 from django import forms
-from django.http import Http404
+from django.forms import widgets
 from django.template import defaultfilters
 from django.utils.encoding import force_text
 from django.utils import html
@@ -35,7 +34,6 @@ from oslo_log import log as logging
 import six
 from yaql import legacy
 
-from muranoclient.common import exceptions as muranoclient_exc
 from muranodashboard.api import packages as pkg_api
 from muranodashboard.common import net
 from muranodashboard.environments import api as env_api
@@ -211,7 +209,7 @@ class CharField(forms.CharField, CustomPropertiesField):
 
 
 class PasswordField(CharField):
-    special_characters = '!@#$%^&*()_+|\/.,~?><:{}'
+    special_characters = '!@#$%^&*()_+|\/.,~?><:{}-'
     password_re = re.compile('^.*(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[%s]).*$'
                              % special_characters)
     has_clone = False
@@ -499,86 +497,9 @@ class FloatingIpBooleanField(BooleanField):
     pass
 
 
-class ClusterIPField(CharField):
-    existing_subnet = None
-    network_topology = None
-    router_id = None
-
-    @staticmethod
-    def make_nova_validator(request, ip_ranges):
-        def perform_checking(ip):
-            django_validator.validate_ipv4_address(ip)
-            if not netaddr.all_matching_cidrs(ip, ip_ranges) and ip_ranges:
-                raise forms.ValidationError(_('Specified Cluster Static IP is'
-                                              ' not in valid IP range'))
-            try:
-                ip_info = nova.novaclient(request).fixed_ips.get(ip)
-            except exceptions.UNAUTHORIZED:
-                LOG.error("Error to get information about IP address"
-                          " using novaclient")
-                exceptions.handle(
-                    request, _("Unable to retrieve information "
-                               "about fixed IP or IP is not valid."),
-                    ignore=True)
-            except exceptions.NOT_FOUND:
-                msg = "Could not found fixed ips for ip %s" % (ip,)
-                LOG.error(msg)
-                exceptions.handle(
-                    request, msg,
-                    ignore=True)
-            else:
-                if ip_info.hostname:
-                    raise forms.ValidationError(
-                        _('Specified Cluster Static IP is already in use'))
-        return perform_checking
-
-    def update_network_params(self, request, environment_id):
-        env = env_api.environment_get(request, environment_id)
-        self.existing_subnet = env.networking.get('cidr')
-        self.network_topology = env.networking.get('topology')
-
-    def make_neutron_validator(self):
-        def perform_checking(ip):
-            django_validator.validate_ipv4_address(ip)
-            if not self.existing_subnet:
-                raise forms.ValidationError(
-                    _('Cannot get allowed subnet for the environment, '
-                      'consult your admin'))
-            elif not netaddr.IPAddress(ip) in netaddr.IPNetwork(
-                    self.existing_subnet):
-                raise forms.ValidationError(
-                    _('Specified IP address should belong to {0} '
-                      'subnet').format(self.existing_subnet))
-
-        return perform_checking
-
-    @with_request
-    def update(self, request, environment_id, **kwargs):
-        self.update_network_params(request, environment_id)
-
-        if self.network_topology == 'nova':
-            try:
-                network_list = nova.novaclient(request).networks.list()
-                ip_ranges = [network.cidr for network in network_list]
-                ranges = ', '.join(ip_ranges)
-            except StandardError:
-                ip_ranges, ranges = [], ''
-            if ip_ranges:
-                self.help_text = _('Select IP from '
-                                   'available range: {0} ').format(ranges)
-            else:
-                self.help_text = _('Specify valid fixed IP')
-            self.validators = [self.make_nova_validator(request, ip_ranges)]
-        elif self.network_topology in ('routed', 'manual'):
-            if self.network_topology == 'manual' and self.router_id is None:
-                raise muranoclient_exc.NotFound(_(
-                    'Router is not found. You should create one explicitly.'))
-            self.widget.attrs['placeholder'] = self.existing_subnet
-            self.validators = [self.make_neutron_validator()]
-        else:  # 'flat' topology
-            raise NotImplementedError('Flat topology is not implemented yet')
-        self.error_messages['invalid'] = \
-            django_validator.validate_ipv4_address.message
+class ClusterIPField(forms.GenericIPAddressField, CustomPropertiesField):
+    def __init__(self, *args, **kwargs):
+        super(ClusterIPField, self).__init__(protocol='ipv4', *args, **kwargs)
 
 
 class DatabaseListField(CharField):
@@ -603,24 +524,37 @@ class DatabaseListField(CharField):
             self.validate_mssql_identifier(db_name)
 
 
+class ErrorWidget(widgets.Widget):
+
+    def __init__(self, *args, **kwargs):
+        self.message = kwargs.pop(
+            'message', _("There was an error initialising this field."))
+        super(ErrorWidget, self).__init__(*args, **kwargs)
+
+    def render(self, name, value, attrs=None):
+        return "<div name={name}>{message}</div>".format(
+            name=name, message=self.message)
+
+
+class MuranoTypeWidget(hz_forms.fields.DynamicSelectWidget):
+    def __init__(self, attrs=None, **kwargs):
+        if attrs is None:
+            attrs = {'class': 'murano_add_select'}
+        else:
+            attrs.setdefault('class', '')
+            attrs['class'] += ' murano_add_select'
+        super(MuranoTypeWidget, self).__init__(attrs=attrs, **kwargs)
+
+    class Media(object):
+        js = ('muranodashboard/js/add-select.js',)
+
+
 def make_select_cls(fqns):
     if not isinstance(fqns, (tuple, list)):
         fqns = (fqns,)
 
-    class Widget(hz_forms.fields.DynamicSelectWidget):
-        def __init__(self, attrs=None, **kwargs):
-            if attrs is None:
-                attrs = {'class': 'murano_add_select'}
-            else:
-                attrs.setdefault('class', '')
-                attrs['class'] += ' murano_add_select'
-            super(Widget, self).__init__(attrs=attrs, **kwargs)
-
-        class Media(object):
-            js = ('muranodashboard/js/add-select.js',)
-
     class DynamicSelect(hz_forms.DynamicChoiceField, CustomPropertiesField):
-        widget = Widget
+        widget = MuranoTypeWidget
 
         def __init__(self, empty_value_message=None, *args, **kwargs):
             super(DynamicSelect, self).__init__(*args, **kwargs)
@@ -631,21 +565,52 @@ def make_select_cls(fqns):
 
         @with_request
         def update(self, request, environment_id, **kwargs):
+            matching_classes = []
+            fqns_seen = set()
+            # NOTE(kzaitsev): it's possible to have a private
+            # and public apps with the same fqn, however the engine would
+            # currently favor private package. Therefore we should squash
+            # these until we devise a better way to work with this
+            # situation and versioning
+
+            for class_fqn in fqns:
+                app_found = pkg_api.app_by_fqn(request, class_fqn)
+                if app_found:
+                    fqns_seen.add(app_found.fully_qualified_name)
+                    matching_classes.append(app_found)
+
+                apps_found = pkg_api.apps_that_inherit(request, class_fqn)
+                for app in apps_found:
+                    if app.fully_qualified_name in fqns_seen:
+                        continue
+                    fqns_seen.add(app.fully_qualified_name)
+                    matching_classes.append(app)
+
+            if not matching_classes:
+                msg = _(
+                    "Couldn't find any apps, required for this field.\n"
+                    "Tried: {fqns}").format(fqns=', '.join(fqns))
+                self.widget = ErrorWidget(message=msg)
+
+            # NOTE(kzaitsev): this closure is needed to allow us have custom
+            # logic when clicking add button
             def _make_link():
                 ns_url = 'horizon:murano:catalog:add'
+                ns_url_args = (environment_id, False, True)
 
-                def _reverse(_fqn):
-                    _app = pkg_api.app_by_fqn(request, _fqn)
-                    if _app is None:
-                        msg = "Application with FQN='{0}' doesn't exist"
-                        messages.error(request, msg.format(_fqn))
-                        raise Http404(msg.format(_fqn))
-                    args = (_app.id, environment_id, False, True)
-                    return _app.name, reverse(ns_url, args=args)
-                return json.dumps([_reverse(cls) for cls in fqns])
+                # This will prevent horizon from adding an extra '+' button
+                if not matching_classes:
+                    return ''
+
+                return json.dumps([
+                    (app.name, reverse(ns_url, args=((app.id,) + ns_url_args)))
+                    for app in matching_classes])
 
             self.widget.add_item_link = _make_link
-            apps = env_api.service_list_by_fqns(request, environment_id, fqns)
+
+            apps = env_api.service_list_by_fqns(
+                request, environment_id,
+                [app.fully_qualified_name for app in matching_classes])
             choices = [('', self.empty_value_message)]
             choices.extend([(app['?']['id'],
                              html.escape(app.name)) for app in apps])
