@@ -50,11 +50,11 @@ def _generate_hostname(pattern, number):
     if pattern:
         # NOTE(kzaitsev) works both for unicode and simple strings in py2
         # and works as expected in py3
-        pattern.replace('#', str(number))
+        return pattern.replace('#', str(number))
 
     counter = _random_string_counter or 1
     # generate first 5 random chars
-    prefix = ''.join(random.choice(string.lowercase) for _ in range(5))
+    prefix = ''.join(random.choice(string.ascii_lowercase) for _ in range(5))
     # convert timestamp to higher base to shorten hostname string
     # (up to 8 chars)
     timestamp = helpers.int2base(int(time.time() * 1000), 36)[:8]
