@@ -12,15 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from collections import OrderedDict
+import collections
 import json
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import tabs
 from openstack_dashboard.api import heat as heat_api
 from openstack_dashboard.api import nova as nova_api
+from openstack_dashboard import policy
 
 from muranoclient.common import exceptions as exc
 from muranodashboard.environments import api
@@ -75,7 +77,7 @@ class OverviewTab(tabs.Tab):
             if id == service_data['?']['status']:
                 status_name = name
 
-        detail_info = OrderedDict([
+        detail_info = collections.OrderedDict([
             ('Name', getattr(service_data, 'name', '')),
             ('ID', service_data['?']['id']),
             ('Type', tables.get_service_type(service_data) or 'Unknown'),
@@ -219,6 +221,13 @@ class EnvironmentServicesTab(tabs.TableTab):
 
         return services
 
+    def get_context_data(self, request, **kwargs):
+        context = super(EnvironmentServicesTab,
+                        self).get_context_data(request, **kwargs)
+        context['MURANO_USE_GLARE'] = getattr(settings, 'MURANO_USE_GLARE',
+                                              False)
+        return context
+
 
 class DeploymentTab(tabs.TableTab):
     slug = "deployments"
@@ -227,6 +236,9 @@ class DeploymentTab(tabs.TableTab):
     template_name = 'horizon/common/_detail_table.html'
     preload = False
 
+    def allowed(self, request):
+        return policy.check((("murano", "list_deployments"),), request)
+
     def get_deployments_data(self):
         deployments = []
         self.environment_id = self.tab_group.kwargs['environment_id']
@@ -251,13 +263,16 @@ class EnvironmentDetailsTabs(tabs.TabGroup):
     slug = "environment_details"
     tabs = (EnvironmentServicesTab, EnvironmentTopologyTab,
             DeploymentTab, LatestLogsTab)
+    sticky = True
 
 
 class ServicesTabs(tabs.TabGroup):
     slug = "services_details"
     tabs = (OverviewTab, ServiceLogsTab)
+    sticky = True
 
 
 class DeploymentDetailsTabs(tabs.TabGroup):
     slug = "deployment_details"
     tabs = (EnvConfigTab, EnvLogsTab,)
+    sticky = True
