@@ -71,6 +71,10 @@ class MarkImageForm(horizon_forms.SelfHandlingForm):
             LOG.error('Failed to request image list from Glance')
             exceptions.handle(request, _('Unable to retrieve list of images'))
 
+        # filter out the image format aki and ari
+        images = filter(
+            lambda x: x.container_format not in ('aki', 'ari'), images)
+
         self.fields['image'].choices = [(i.id, i.name) for i in images]
         self.fields['existing_titles'].initial = \
             [image.title for image in filter_murano_images(images)]
@@ -79,14 +83,13 @@ class MarkImageForm(horizon_forms.SelfHandlingForm):
         LOG.debug('Marking image with specified metadata: {0}'.format(data))
 
         image_id = data['image']
-        properties = glance.image_get(request, image_id).properties
-        properties['murano_image_info'] = json.dumps({
+        kwargs = {}
+        kwargs['murano_image_info'] = json.dumps({
             'title': data['title'],
             'type': data['type']
         })
-
         try:
-            img = glance.image_update(request, image_id, properties=properties)
+            img = glance.image_update_properties(request, image_id, **kwargs)
             messages.success(request, _('Image successfully marked'))
             return img
         except Exception:
