@@ -19,6 +19,8 @@ from horizon import exceptions
 from horizon import tables
 from openstack_dashboard.api import glance
 
+from muranodashboard.common import utils as md_utils
+
 
 class MarkImage(tables.LinkAction):
     name = "mark_image"
@@ -50,10 +52,8 @@ class RemoveImageMetadata(tables.DeleteAction):
 
     def delete(self, request, obj_id):
         try:
-            properties = glance.image_get(request, obj_id).properties
-            properties.pop('murano_image_info', None)
-            glance.image_update(request, obj_id, properties=properties,
-                                purge_props=True)
+            remove_props = ['murano_image_info']
+            glance.image_update_properties(request, obj_id, remove_props)
         except Exception:
             exceptions.handle(request, _('Unable to remove metadata'),
                               redirect=reverse('horizon:murano:images:index'))
@@ -70,9 +70,8 @@ class MarkedImagesTable(tables.DataTable):
     )
     type = tables.Column(lambda obj: getattr(obj, 'type', None),
                          verbose_name=_('Type'))
-    title = tables.Column(lambda obj: getattr(obj, 'title', None),
-                          verbose_name=_('Title'),
-                          truncate=40)
+    title = md_utils.Column(lambda obj: getattr(obj, 'title', None),
+                            verbose_name=_('Title'))
 
     class Meta(object):
         name = 'marked_images'
