@@ -13,7 +13,6 @@
 #    under the License.
 
 from django.core.urlresolvers import reverse
-from django import http
 from django.template import defaultfilters
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
@@ -21,10 +20,12 @@ from horizon import exceptions
 from horizon import messages
 from horizon import tables
 from horizon.utils import filters
+from openstack_dashboard import policy
 from oslo_log import log as logging
 
 from muranoclient.common import exceptions as exc
 from muranodashboard import api
+from muranodashboard.common import utils as md_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -35,6 +36,7 @@ class ImportBundle(tables.LinkAction):
     url = 'horizon:murano:packages:import_bundle'
     classes = ('ajax-modal',)
     icon = "plus"
+    policy_rules = (("murano", "upload_package"),)
 
 
 class ImportPackage(tables.LinkAction):
@@ -43,6 +45,7 @@ class ImportPackage(tables.LinkAction):
     url = 'horizon:murano:packages:upload'
     classes = ('ajax-modal',)
     icon = "plus"
+    policy_rules = (("murano", "upload_package"),)
 
     def allowed(self, request, package):
         _allowed = False
@@ -60,44 +63,25 @@ class PackagesFilterAction(tables.FilterAction):
                       ('name', _("Name"), True))
 
 
-class DownloadPackage(tables.Action):
+class DownloadPackage(tables.LinkAction):
     name = 'download_package'
     verbose_name = _('Download Package')
+    url = 'horizon:murano:packages:download'
+    policy_rules = (("murano", "download_package"),)
 
     def allowed(self, request, package):
         return True
 
-    @staticmethod
-    def get_package_name(data_table, app_id):
-        # TODO(tsufiev): should use more optimal search here
-        name = None
-        for pkg in data_table.data:
-            if pkg.id == app_id:
-                name = defaultfilters.slugify(pkg.name)
-                break
-        return name if name is not None else app_id
-
-    def single(self, data_table, request, app_id):
-        try:
-            body = api.muranoclient(request).packages.download(app_id)
-
-            content_type = 'application/octet-stream'
-            response = http.HttpResponse(body, content_type=content_type)
-            response['Content-Disposition'] = 'filename={name}.zip'.format(
-                name=self.get_package_name(data_table, app_id))
-            return response
-        except exc.HTTPException:
-            LOG.exception(_('Something went wrong during package downloading'))
-            redirect = reverse('horizon:murano:packages:index')
-            exceptions.handle(request,
-                              _('Unable to download package.'),
-                              redirect=redirect)
+    def get_link_url(self, app):
+        app_name = defaultfilters.slugify(app.name)
+        return reverse(self.url, args=(app_name, app.id))
 
 
 class ToggleEnabled(tables.BatchAction):
     name = 'toggle_enabled'
     verbose_name = _("Toggle Enabled")
     icon = "toggle-on"
+    policy_rules = (("murano", "modify_package"),)
 
     @staticmethod
     def action_present(count):
@@ -133,6 +117,7 @@ class TogglePublicEnabled(tables.BatchAction):
     name = 'toggle_public_enabled'
     verbose_name = _("Toggle Public")
     icon = "share-alt"
+    policy_rules = (("murano", "publicize_package"),)
 
     @staticmethod
     def action_present(count):
@@ -173,8 +158,9 @@ class TogglePublicEnabled(tables.BatchAction):
                 redirect=reverse('horizon:murano:packages:index'))
 
 
-class DeletePackage(tables.DeleteAction):
+class DeletePackage(policy.PolicyTargetMixin, tables.DeleteAction):
     name = 'delete_package'
+    policy_rules = (("murano", "delete_package"),)
 
     @staticmethod
     def action_present(count):
@@ -222,15 +208,17 @@ class ModifyPackage(tables.LinkAction):
     url = 'horizon:murano:packages:modify'
     classes = ('ajax-modal',)
     icon = "edit"
+    policy_rules = (("murano", "modify_package"),)
 
     def allowed(self, request, package):
         return True
 
 
 class PackageDefinitionsTable(tables.DataTable):
-    name = tables.Column('name',
-                         link="horizon:murano:packages:detail",
-                         verbose_name=_('Package Name'))
+    name = md_utils.Column(
+        'name',
+        link="horizon:murano:packages:detail",
+        verbose_name=_('Package Name'))
     tenant_name = tables.Column('tenant_name', verbose_name=_('Tenant Name'))
     enabled = tables.Column('enabled', verbose_name=_('Active'))
     is_public = tables.Column('is_public', verbose_name=_('Public'))
